<?php
/**
 * @package    Bongovo Installer plugin
 *
 * @author     Pavel Poles - n3t.cz
 * @copyright  © 2022 Pavel Poles - n3t.cz. All rights reserved.
 * @license    GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 * @link       https://n3t.bitbucket.io
*/

defined('_JEXEC') or die;

use Joomla\CMS\Language\Text;

/** @var PlgInstallerBongovo $this */
/** @var array $translations */

?>
<table class="table itemList" id="translationsList">
  <caption class="visually-hidden hidden">
	  <?php echo Text::_('PLG_INSTALLER_BONGOVO_TEXT'); ?>
  </caption>

  <thead>
  <tr>
    <th scope="col">
	    <?php echo Text::_('PLG_INSTALLER_BONGOVO_TH_NAME'); ?>
    </th>
    <th scope="col" class="w-10 text-center d-none d-md-table-cell">
		  <?php echo Text::_('PLG_INSTALLER_BONGOVO_TH_LANGUAGE'); ?>
    </th>
    <th scope="col" class="w-10 text-center d-none d-md-table-cell">
		  <?php echo Text::_('PLG_INSTALLER_BONGOVO_TH_EXTENSION'); ?>
    </th>
    <th scope="col" class="w-10 text-center d-none d-md-table-cell">
		  <?php echo Text::_('PLG_INSTALLER_BONGOVO_TH_VERSION'); ?>
    </th>
    <th scope="col" class="w-5">&nbsp;</th>
  </tr>
  </thead>

  <tbody>
<?php
foreach ($translations as $translation) {
  $btnClass = 'primary';
	$btnText = 'PLG_INSTALLER_BONGOVO_BTN_INSTALL';
  if ($translation->installedversion) {
    if ($translation->version && version_compare($translation->version, $translation->installedversion, '>')) {
	    $btnClass = 'warning';
	    $btnText = 'PLG_INSTALLER_BONGOVO_BTN_UPDATE';
    } else {
	    $btnClass = 'success';
	    $btnText = 'PLG_INSTALLER_BONGOVO_BTN_REINSTALL';
    }
  }
?>
  <tr class="row1" data-draggable-group="9" data-transitions="">
    <td class="text-left">
      <div class="break-word"><?php echo $translation->name; ?></div>
      <div class="small break-word"><?php echo $translation->description; ?></div>
    </td>
    <td class="text-center d-none d-md-table-cell">
	    <?php if ($translation->language) { ?>
	      <?php if ($translation->languageinstalled) { ?>
          <span class="badge badge-success bg-success" title="<?php echo Text::_('PLG_INSTALLER_BONGOVO_LANGUAGE_INSTALLED'); ?>"><?php echo $translation->language; ?></span>
	    <?php } else { ?>
          <span class="badge bg-secondary" title="<?php echo Text::_('PLG_INSTALLER_BONGOVO_LANGUAGE_NOT_INSTALLED'); ?>"><?php echo $translation->language; ?></span>
	    <?php } ?>
	    <?php } ?>
    </td>
    <td class="text-center d-none d-md-table-cell">
	    <?php if($translation->extensionversion) { ?>
        <span class="badge bg-secondary">
		    <?php echo $translation->extensionversion; ?>
        </span>
	    <?php } ?>
    </td>
    <td class="text-center d-none d-md-table-cell">
      <?php if ($translation->version && $translation->installedversion && version_compare($translation->version, $translation->installedversion, '>')) { ?>
        <span class="badge bg-warning text-dark" title="<?php echo Text::_('PLG_INSTALLER_BONGOVO_UPDATE_AVAILABLE'); ?>"><?php echo $translation->version; ?></span>
      <?php } elseif ($translation->version) { ?>
      <span class="badge badge-success bg-success"><?php echo $translation->version; ?></span>
      <?php } ?>
    </td>
    <td class="text-end">
		  <?php if ($translation->detailsurl) { ?>
        <a href="#" class="btn btn-<?php echo $btnClass ?> btn-sm" onclick="bongovoInstall('<?php echo $translation->detailsurl; ?>'); return false;">
				  <?php echo Text::_($btnText) ?>
        </a>
		  <?php } ?>
    </td>
  </tr>
<?php
}
?>
  </tbody>
</table>
